# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.api_authorization_server_api import APIAuthorizationServerApi  # noqa: E501
from onelogin.rest import ApiException


class TestAPIAuthorizationServerApi(unittest.TestCase):
    """APIAuthorizationServerApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.api_authorization_server_api.APIAuthorizationServerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_auth_server(self):
        """Test case for create_auth_server

        Create Api Auth Server  # noqa: E501
        """
        pass

    def test_delete_auth_server(self):
        """Test case for delete_auth_server

        Delete Api Auth Server  # noqa: E501
        """
        pass

    def test_get_auth_server(self):
        """Test case for get_auth_server

        Get Api Auth Server  # noqa: E501
        """
        pass

    def test_list_auth_servers(self):
        """Test case for list_auth_servers

        List Api Auth Servers  # noqa: E501
        """
        pass

    def test_update_auth_server(self):
        """Test case for update_auth_server

        Update Api Auth Server  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
