# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.branding_service_templates_api import BrandingServiceTemplatesApi  # noqa: E501
from onelogin.rest import ApiException


class TestBrandingServiceTemplatesApi(unittest.TestCase):
    """BrandingServiceTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.branding_service_templates_api.BrandingServiceTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_message_template(self):
        """Test case for create_message_template

        Create Message Template  # noqa: E501
        """
        pass

    def test_delete_message_template(self):
        """Test case for delete_message_template

        Delete Message Template  # noqa: E501
        """
        pass

    def test_get_master_by_type(self):
        """Test case for get_master_by_type

        Get Master Template by Type  # noqa: E501
        """
        pass

    def test_get_message_template_by_id(self):
        """Test case for get_message_template_by_id

        Get Message Template  # noqa: E501
        """
        pass

    def test_get_template_by_locale(self):
        """Test case for get_template_by_locale

        Get Template by Type & Locale  # noqa: E501
        """
        pass

    def test_list_message_templates(self):
        """Test case for list_message_templates

        List Message Templates  # noqa: E501
        """
        pass

    def test_update_message_template_by_id(self):
        """Test case for update_message_template_by_id

        Update Message Template  # noqa: E501
        """
        pass

    def test_update_template_by_locale(self):
        """Test case for update_template_by_locale

        Update Template by Type & Locale  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
