# flake8: noqa

# import apis into api package
from onelogin.api.api_auth_claims_api import APIAuthClaimsApi
from onelogin.api.api_auth_client_apps_api import APIAuthClientAppsApi
from onelogin.api.api_auth_scopes_api import APIAuthScopesApi
from onelogin.api.api_authorization_server_api import APIAuthorizationServerApi
from onelogin.api.app_rules_api import AppRulesApi
from onelogin.api.apps_api import AppsApi
from onelogin.api.branding_service_api import BrandingServiceApi
from onelogin.api.branding_service_smtp_api import BrandingServiceSMTPApi
from onelogin.api.branding_service_templates_api import BrandingServiceTemplatesApi
from onelogin.api.events_api import EventsApi
from onelogin.api.groups_api import GroupsApi
from onelogin.api.invite_links_api import InviteLinksApi
from onelogin.api.multi_factor_authentication_api import MultiFactorAuthenticationApi
from onelogin.api.multi_factor_authentication_v1_api import MultiFactorAuthenticationV1Api
from onelogin.api.o_auth2_api import OAuth2Api
from onelogin.api.privileges_api import PrivilegesApi
from onelogin.api.roles_api import RolesApi
from onelogin.api.saml_assertions_api import SAMLAssertionsApi
from onelogin.api.smart_hooks_api import SmartHooksApi
from onelogin.api.user_mappings_api import UserMappingsApi
from onelogin.api.users_v1_api import UsersV1Api
from onelogin.api.users_v2_api import UsersV2Api
from onelogin.api.vigilance_ai_api import VigilanceAIApi

