# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.enforcement_point import EnforcementPoint  # noqa: E501
from onelogin.rest import ApiException

class TestEnforcementPoint(unittest.TestCase):
    """EnforcementPoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EnforcementPoint
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EnforcementPoint`
        """
        model = onelogin.models.enforcement_point.EnforcementPoint()  # noqa: E501
        if include_optional :
            return EnforcementPoint(
                require_sitewide_authentication = False, 
                conditions = '', 
                session_expiry_fixed = {"value":30,"unit":1}, 
                session_expiry_inactivity = {"value":30,"unit":1}, 
                permissions = 'allow', 
                token = 'b491c647f5e0cff854ad606722ac98342b4b0882', 
                target = '', 
                resources = [{"resource_id":809,"conditions":"","is_path_regex":false,"permissions":"allow","require_auth":false,"path":"/"}], 
                context_root = '/', 
                use_target_host_header = False, 
                vhost = '', 
                landing_page = '', 
                case_sensitive = False
            )
        else :
            return EnforcementPoint(
        )
        """

    def testEnforcementPoint(self):
        """Test EnforcementPoint"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
