# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.multi_factor_authentication_api import MultiFactorAuthenticationApi  # noqa: E501
from onelogin.rest import ApiException


class TestMultiFactorAuthenticationApi(unittest.TestCase):
    """MultiFactorAuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.multi_factor_authentication_api.MultiFactorAuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_device_verification(self):
        """Test case for create_device_verification

        Create Device Verification  # noqa: E501
        """
        pass

    def test_create_factor_registration(self):
        """Test case for create_factor_registration

        Create Factor Registration  # noqa: E501
        """
        pass

    def test_delete_enrolled_factor(self):
        """Test case for delete_enrolled_factor

        Delete Enrolled Factor  # noqa: E501
        """
        pass

    def test_generate_otp(self):
        """Test case for generate_otp

        Generate MFA token  # noqa: E501
        """
        pass

    def test_get_auth_factors(self):
        """Test case for get_auth_factors

        Get User Factors  # noqa: E501
        """
        pass

    def test_get_authentication_devices(self):
        """Test case for get_authentication_devices

        Get User Devices  # noqa: E501
        """
        pass

    def test_get_user_registration(self):
        """Test case for get_user_registration

        Get User Registration  # noqa: E501
        """
        pass

    def test_get_user_verification(self):
        """Test case for get_user_verification

        Get User Verification  # noqa: E501
        """
        pass

    def test_verify_user_registration(self):
        """Test case for verify_user_registration

        Verify User Registration  # noqa: E501
        """
        pass

    def test_verify_user_verification(self):
        """Test case for verify_user_verification

        Verify User Verification  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
