# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.app_rules_api import AppRulesApi  # noqa: E501
from onelogin.rest import ApiException


class TestAppRulesApi(unittest.TestCase):
    """AppRulesApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.app_rules_api.AppRulesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_app_rule(self):
        """Test case for create_app_rule

        """
        pass

    def test_delete_rule(self):
        """Test case for delete_rule

        Delete Rule  # noqa: E501
        """
        pass

    def test_get_app_rule(self):
        """Test case for get_app_rule

        Get Rule  # noqa: E501
        """
        pass

    def test_list_action_valies(self):
        """Test case for list_action_valies

        List Actions Values  # noqa: E501
        """
        pass

    def test_list_actions(self):
        """Test case for list_actions

        List Actions  # noqa: E501
        """
        pass

    def test_list_app_rules(self):
        """Test case for list_app_rules

        List Rules  # noqa: E501
        """
        pass

    def test_list_condition_operators(self):
        """Test case for list_condition_operators

        List Conditions Operators  # noqa: E501
        """
        pass

    def test_list_condition_values(self):
        """Test case for list_condition_values

        List Conditions Values  # noqa: E501
        """
        pass

    def test_list_conditions(self):
        """Test case for list_conditions

        List Conditions  # noqa: E501
        """
        pass

    def test_sort_app_rules(self):
        """Test case for sort_app_rules

        Bulk Sort  # noqa: E501
        """
        pass

    def test_update_app_rule(self):
        """Test case for update_app_rule

        Update Rule  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
