# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.saml_assertions_api import SAMLAssertionsApi  # noqa: E501
from onelogin.rest import ApiException


class TestSAMLAssertionsApi(unittest.TestCase):
    """SAMLAssertionsApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.saml_assertions_api.SAMLAssertionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_saml_assert(self):
        """Test case for generate_saml_assert

        Generate SAML Assertion  # noqa: E501
        """
        pass

    def test_generate_saml_assert2(self):
        """Test case for generate_saml_assert2

        Generate SAML Assertion  # noqa: E501
        """
        pass

    def test_ver_factor_saml(self):
        """Test case for ver_factor_saml

        Verify Factor SAML  # noqa: E501
        """
        pass

    def test_ver_factor_saml2(self):
        """Test case for ver_factor_saml2

        Verify Factor SAML  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
