# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.users_v1_api import UsersV1Api  # noqa: E501
from onelogin.rest import ApiException


class TestUsersV1Api(unittest.TestCase):
    """UsersV1Api unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.users_v1_api.UsersV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_roles_to_user(self):
        """Test case for add_roles_to_user

        Add Roles for a User  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Create a User  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete a User  # noqa: E501
        """
        pass

    def test_get_custom_attributes(self):
        """Test case for get_custom_attributes

        Get Custom Attributes  # noqa: E501
        """
        pass

    def test_get_user_apps(self):
        """Test case for get_user_apps

        Get Apps for a User  # noqa: E501
        """
        pass

    def test_get_user_by_id(self):
        """Test case for get_user_by_id

        Get User by ID  # noqa: E501
        """
        pass

    def test_get_user_roles(self):
        """Test case for get_user_roles

        Get Roles for a User  # noqa: E501
        """
        pass

    def test_list_users(self):
        """Test case for list_users

        List Users  # noqa: E501
        """
        pass

    def test_lock_account_user(self):
        """Test case for lock_account_user

        Lock User Account  # noqa: E501
        """
        pass

    def test_log_out_user(self):
        """Test case for log_out_user

        Log User Out  # noqa: E501
        """
        pass

    def test_remove_user_role(self):
        """Test case for remove_user_role

        Remove Roles for a User  # noqa: E501
        """
        pass

    def test_set_user_state(self):
        """Test case for set_user_state

        Set User State  # noqa: E501
        """
        pass

    def test_update_password_insecure(self):
        """Test case for update_password_insecure

        Set Password Using ID in Cleartext  # noqa: E501
        """
        pass

    def test_update_password_secure(self):
        """Test case for update_password_secure

        Set Password Using ID and SHA-256 and Salt  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Update a User  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
