# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.verb import Verb  # noqa: E501
from onelogin.rest import ApiException

class TestVerb(unittest.TestCase):
    """Verb unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVerb(self):
        """Test Verb"""
        # inst = Verb()

if __name__ == '__main__':
    unittest.main()
