# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.oidc_app_all_of import OidcAppAllOf  # noqa: E501
from onelogin.rest import ApiException

class TestOidcAppAllOf(unittest.TestCase):
    """OidcAppAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OidcAppAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OidcAppAllOf`
        """
        model = onelogin.models.oidc_app_all_of.OidcAppAllOf()  # noqa: E501
        if include_optional :
            return OidcAppAllOf(
                configuration = onelogin.models.configuration_oidc.configuration_oidc(
                    login_url = '', 
                    redirect_uri = 'https://localhost:3000/callback', 
                    access_token_expiration_minutes = 1, 
                    refresh_token_expiration_minutes = 1, 
                    token_endpoint_auth_method = 0, 
                    oidc_application_type = 0, ), 
                sso = onelogin.models.sso_oidc.sso_oidc(
                    client_id = '78d1d040-20c9-0136-5146-067351775fae92920', )
            )
        else :
            return OidcAppAllOf(
                configuration = onelogin.models.configuration_oidc.configuration_oidc(
                    login_url = '', 
                    redirect_uri = 'https://localhost:3000/callback', 
                    access_token_expiration_minutes = 1, 
                    refresh_token_expiration_minutes = 1, 
                    token_endpoint_auth_method = 0, 
                    oidc_application_type = 0, ),
        )
        """

    def testOidcAppAllOf(self):
        """Test OidcAppAllOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
