# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.create_device_verification201_response import CreateDeviceVerification201Response  # noqa: E501
from onelogin.rest import ApiException

class TestCreateDeviceVerification201Response(unittest.TestCase):
    """CreateDeviceVerification201Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateDeviceVerification201Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateDeviceVerification201Response`
        """
        model = onelogin.models.create_device_verification201_response.CreateDeviceVerification201Response()  # noqa: E501
        if include_optional :
            return CreateDeviceVerification201Response(
                device_id = 58959, 
                display_name = 'OneLogin SMS', 
                expires_at = '2020-07-11T22:24:50Z', 
                redirect_to = '', 
                user_display_name = 'OneLogin Voice', 
                id = '44aa6883-5048-4cd5-8cb2-64d47784230c', 
                type_display_name = 'OneLogin Voice', 
                auth_factor_name = 'OneLogin Voice'
            )
        else :
            return CreateDeviceVerification201Response(
        )
        """

    def testCreateDeviceVerification201Response(self):
        """Test CreateDeviceVerification201Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
