# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.hook import Hook  # noqa: E501
from onelogin.rest import ApiException

class TestHook(unittest.TestCase):
    """Hook unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Hook
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Hook`
        """
        model = onelogin.models.hook.Hook()  # noqa: E501
        if include_optional :
            return Hook(
                id = '', 
                type = '', 
                disabled = True, 
                timeout = 56, 
                env_vars = [
                    ''
                    ], 
                runtime = '', 
                retries = 56, 
                packages = {
                    'key' : ''
                    }, 
                function = '', 
                context_version = '', 
                status = 'ready', 
                options = onelogin.models.hook_options.hook_options(
                    risk_enabled = True, 
                    location_enabled = True, 
                    mfa_device_info_enabled = True, ), 
                conditions = [
                    onelogin.models.condition.condition(
                        source = 'last_login', 
                        operator = '>', 
                        value = '90', )
                    ], 
                created_at = '', 
                updated_at = ''
            )
        else :
            return Hook(
                type = '',
                disabled = True,
                timeout = 56,
                env_vars = [
                    ''
                    ],
                runtime = '',
                retries = 56,
                packages = {
                    'key' : ''
                    },
                function = '',
        )
        """

    def testHook(self):
        """Test Hook"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
