# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.app_rule import AppRule  # noqa: E501
from onelogin.rest import ApiException

class TestAppRule(unittest.TestCase):
    """AppRule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AppRule
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppRule`
        """
        model = onelogin.models.app_rule.AppRule()  # noqa: E501
        if include_optional :
            return AppRule(
                id = 196670, 
                name = 'My first app rule', 
                match = 'all', 
                enabled = True, 
                position = 1, 
                conditions = [
                    onelogin.models.condition.condition(
                        source = 'last_login', 
                        operator = '>', 
                        value = '90', )
                    ], 
                actions = [
                    onelogin.models.action_obj.action_obj(
                        action = '', 
                        value = [
                            '2'
                            ], )
                    ]
            )
        else :
            return AppRule(
        )
        """

    def testAppRule(self):
        """Test AppRule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
