# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.branding_service_api import BrandingServiceApi  # noqa: E501
from onelogin.rest import ApiException


class TestBrandingServiceApi(unittest.TestCase):
    """BrandingServiceApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.branding_service_api.BrandingServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_brand(self):
        """Test case for create_brand

        Create Brand  # noqa: E501
        """
        pass

    def test_delete_brand(self):
        """Test case for delete_brand

        Delete Brand  # noqa: E501
        """
        pass

    def test_get_brand(self):
        """Test case for get_brand

        Get Brand  # noqa: E501
        """
        pass

    def test_get_brand_apps(self):
        """Test case for get_brand_apps

        Get Brand Apps  # noqa: E501
        """
        pass

    def test_list_brands(self):
        """Test case for list_brands

        List Account Brands  # noqa: E501
        """
        pass

    def test_update_brand(self):
        """Test case for update_brand

        Update Brand  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
