# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.privileges_api import PrivilegesApi  # noqa: E501
from onelogin.rest import ApiException


class TestPrivilegesApi(unittest.TestCase):
    """PrivilegesApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.privileges_api.PrivilegesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_privilege_to_role(self):
        """Test case for add_privilege_to_role

        Assign a Privilege to Roles  # noqa: E501
        """
        pass

    def test_assign_users_to_privilege(self):
        """Test case for assign_users_to_privilege

        Assign Users to a Privilege  # noqa: E501
        """
        pass

    def test_create_privilege(self):
        """Test case for create_privilege

        Create a Privilege  # noqa: E501
        """
        pass

    def test_delete_privilege(self):
        """Test case for delete_privilege

        Delete a Privilege  # noqa: E501
        """
        pass

    def test_delete_role_from_privilege(self):
        """Test case for delete_role_from_privilege

        Remove a Privilege from a Role  # noqa: E501
        """
        pass

    def test_get_assigned_user(self):
        """Test case for get_assigned_user

        Get Users assigned to a Privilege  # noqa: E501
        """
        pass

    def test_get_privilege(self):
        """Test case for get_privilege

        Get a Privilege  # noqa: E501
        """
        pass

    def test_list_privelege_roles(self):
        """Test case for list_privelege_roles

        Get Roles assigned to Privilege  # noqa: E501
        """
        pass

    def test_list_priveleges(self):
        """Test case for list_priveleges

        List Privileges  # noqa: E501
        """
        pass

    def test_remove_user_from_privilege(self):
        """Test case for remove_user_from_privilege

        Remove a Privilege from Users  # noqa: E501
        """
        pass

    def test_update_privilege(self):
        """Test case for update_privilege

        Update a Privilege  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
