# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.privilege_privilege_statement_inner import PrivilegePrivilegeStatementInner  # noqa: E501
from onelogin.rest import ApiException

class TestPrivilegePrivilegeStatementInner(unittest.TestCase):
    """PrivilegePrivilegeStatementInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrivilegePrivilegeStatementInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PrivilegePrivilegeStatementInner`
        """
        model = onelogin.models.privilege_privilege_statement_inner.PrivilegePrivilegeStatementInner()  # noqa: E501
        if include_optional :
            return PrivilegePrivilegeStatementInner(
                effect = 'Allow', 
                action = ["Users:Delete","Users:ResetPassword","Users:Unlock","Users:Get"], 
                scope = [
                    '*'
                    ]
            )
        else :
            return PrivilegePrivilegeStatementInner(
                effect = 'Allow',
                action = ["Users:Delete","Users:ResetPassword","Users:Unlock","Users:Get"],
                scope = [
                    '*'
                    ],
        )
        """

    def testPrivilegePrivilegeStatementInner(self):
        """Test PrivilegePrivilegeStatementInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
