# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.users_v2_api import UsersV2Api  # noqa: E501
from onelogin.rest import ApiException


class TestUsersV2Api(unittest.TestCase):
    """UsersV2Api unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.users_v2_api.UsersV2Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_user2(self):
        """Test case for create_user2

        Create User  # noqa: E501
        """
        pass

    def test_delete_user2(self):
        """Test case for delete_user2

        Delete User  # noqa: E501
        """
        pass

    def test_get_user2(self):
        """Test case for get_user2

        Get User  # noqa: E501
        """
        pass

    def test_get_user_apps2(self):
        """Test case for get_user_apps2

        Get User Apps  # noqa: E501
        """
        pass

    def test_list_users2(self):
        """Test case for list_users2

        List Users  # noqa: E501
        """
        pass

    def test_update_user2(self):
        """Test case for update_user2

        Update User  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
