# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.message_template import MessageTemplate  # noqa: E501
from onelogin.rest import ApiException

class TestMessageTemplate(unittest.TestCase):
    """MessageTemplate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MessageTemplate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MessageTemplate`
        """
        model = onelogin.models.message_template.MessageTemplate()  # noqa: E501
        if include_optional :
            return MessageTemplate(
                id = 544880, 
                account_id = 118462, 
                type = 'email_forgot_password', 
                locale = 'en', 
                template = None, 
                template_class = 'email_template', 
                updated_at = '2021-11-24T21:25:29.480Z', 
                brand_id = 5
            )
        else :
            return MessageTemplate(
                type = 'email_forgot_password',
                locale = 'en',
                template = None,
        )
        """

    def testMessageTemplate(self):
        """Test MessageTemplate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
