# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.invite_links_api import InviteLinksApi  # noqa: E501
from onelogin.rest import ApiException


class TestInviteLinksApi(unittest.TestCase):
    """InviteLinksApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.invite_links_api.InviteLinksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_invite_link(self):
        """Test case for get_invite_link

        Generate Invite Link  # noqa: E501
        """
        pass

    def test_send_invite_link(self):
        """Test case for send_invite_link

        Send  Invite Link  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
