# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.auth_server import AuthServer  # noqa: E501
from onelogin.rest import ApiException

class TestAuthServer(unittest.TestCase):
    """AuthServer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AuthServer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthServer`
        """
        model = onelogin.models.auth_server.AuthServer()  # noqa: E501
        if include_optional :
            return AuthServer(
                id = 1022697, 
                name = 'Contacts API', 
                description = 'API manages contacts', 
                configuration = onelogin.models.auth_server_configuration.auth_server_configuration(
                    audiences = [
                        ''
                        ], 
                    refresh_token_expiration_minutes = 30, 
                    resource_identifier = 'https://example.com/contacts', 
                    access_token_expiration_minutes = 20, )
            )
        else :
            return AuthServer(
                name = 'Contacts API',
                description = 'API manages contacts',
                configuration = onelogin.models.auth_server_configuration.auth_server_configuration(
                    audiences = [
                        ''
                        ], 
                    refresh_token_expiration_minutes = 30, 
                    resource_identifier = 'https://example.com/contacts', 
                    access_token_expiration_minutes = 20, ),
        )
        """

    def testAuthServer(self):
        """Test AuthServer"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
