# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.brand_app import BrandApp  # noqa: E501
from onelogin.rest import ApiException

class TestBrandApp(unittest.TestCase):
    """BrandApp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BrandApp
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BrandApp`
        """
        model = onelogin.models.brand_app.BrandApp()  # noqa: E501
        if include_optional :
            return BrandApp(
                id = 1455, 
                updated_at = '2020-09-11T19:35:08.288Z', 
                name = 'Mom Corp', 
                connector_id = 3001, 
                auth_method_description = 'SAML2.0', 
                description = 'Mom’s Friendly Robot Company', 
                auth_method = 2, 
                created_at = '2020-09-08T22:24:19.551Z', 
                visible = True
            )
        else :
            return BrandApp(
                id = 1455,
                updated_at = '2020-09-11T19:35:08.288Z',
                name = 'Mom Corp',
                connector_id = 3001,
                auth_method_description = 'SAML2.0',
                description = 'Mom’s Friendly Robot Company',
                auth_method = 2,
                created_at = '2020-09-08T22:24:19.551Z',
                visible = True,
        )
        """

    def testBrandApp(self):
        """Test BrandApp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
